lauantaina, maaliskuuta 29, 2008
Ubuntu 8.04 beta!
Pieniä ongelmia oli asennuksessa mikä liittyi kieleen.
Täältä löytyy asennus video ekasta yrittämisestä.
Mutta toisella yrittämisellä jo onnistu kun valitsi asennuskieleksi englannin.
Ja vielä pientä testiä miten toimii käynnistyksen jälkeen.
Tässä tapauksessa joutui erikseen asentamaan suomenkielen jotta ubuntu olisi ollut edes puoliksi suomeksi. Mutta englantikin käy jos sitä ei vieroksu ;).
perjantaina, maaliskuuta 14, 2008
Äänissä oli pientä säätöä jotta ne lähti toimimaan, muuten kaikki pelaa niin kuin pitääkin.
Tämä operaatio on hyvin yksinkertainen, eli:
cd /etc
Editoi modules tiedostoa
sudo nano modules
sinne uusirivi viimeiseksi:
snd-cs4236
Sitten vain bootti niin äänet pelaa.
Kuva löytyy täältä
torstaina, helmikuuta 28, 2008
Ostin USB-digiboxin Anysee E30 C Plus. Ja ensin ajattelin kokeilla miten se toimii XP:ssä ja sitten sen jälkeen kubuntussa.
XP:ssä asennus tyssäsi mystiseen kaatumiseen, ja asennus piti suorittaa uudestaan jolloinka se taas kaatui mystisesti. Lopulta asensin ajurit käsin. Noh ohjelma lähti kuin lähti pelittämään, mutta kanavan haussa ohjelma kaatu ilmoittaen Codecin puuttumisesta tai että USB kaapeli ei ole kytketty :D. Vaikka varmasti oli kytketty kun ilmoitti että "havaittu uusi laite".
En jaksanut enää sitten tapella XP:ssä vaan päätin suosiolla kokeilla digiboxia Kubuntussa.
Seuraavilla ohjeilla se tapahtuu:
sudo apt-get install mercurial linux-headers-$(uname -r) build-essential
hg clone http://linuxtv.org/hg/~anttip/anysee/
cd anysee
make
sudo make install
Ohjeet löydät ubuntu foorumilta ja keskustelua aiheesta enemmän.
Ja sehän lähti heti toimimaan. Kaffeinea käynnistäessä, kun olin ensin bootannut koneen tuli seuraavanlainen ilmoitus. ks. kuva.
Valitsin vain mikä lähde ja ok.
Kaukosäätimessä toimi ainakin mute ja volume nappi. Ja myös kanavan vaihtaminen numeroilla onnistui. Myös lähetyksen tallentaminen sujui ongelmitta.
Kortinlukijalle ei ole vielä tukea, mutta lupasivat foorumilla että sekin tulee aikanaa.
Tästä voidaan tehdä johtopäätös: Linux on parempi kuin XP :) tai mikä tahansa muu windows jakelu.
sunnuntaina, helmikuuta 24, 2008
Joka liittyy tietokone lehden uutiseen 22.2.2008 "Microsoft lupaa taas avoimuutta ja yhteensopivuutta".
Mikähän mahtaa olla m$ käsite avoimuudesta??? "Ohjelmistoyhtiö lupaa kertoa myös protokolliensa patenteista ja tarjota näitä käyttöön kohtuulliseen hintaan. Lisäksi yhtiö vakuuttaa, ettei asiakkaita ja kumppaneita syrjtä siinä, miten ne saavat patentoitua tietoa käyttöönsä." Ilmaisu kohtuullinen hinta = m$ avoin :D.
Viimevuosina on ollut pelkkää oikeustaistelua avoimen koodin ja microsoftin tai sen kumppaneiden välillä. Joten varmasti se jatkuu vaikka lupaavatkin seuraavaa:
Microsoftin ilmoittaa, ettei sellaisia avoimen koodin ohjelmistojen valmistajia haasteta oikeuteen, jotka hyödyntävät Microsoftn patentoimia tekniikoita ei-kaupallisesti.
Eli varsin mielenkiintoinen uutinen ja joka myös koskettaa kaikkia Linux käyttäjiä.
sunnuntaina, tammikuuta 20, 2008
Kubuntun salat osa2!

Komento:
sudo kate /etc/usplash.conf
Tuolla tiedostossa on lataus kuvan resoluutio arvot.
Ja muuta seuraavanlaiseksi arvot: xres=1024 yres=768
Tiedosto saattaa näyttää seuraavalta:
# Usplash configuration file
#xres=1280
#yres=1024
Kubuntun salat osa1!
Jos joskus joutuu asentamaan Kubuntun uudestaan ja haluaa kopioida tarvittavia tietoja talteen esim. tässä tapauksessa Etäyhteydet (remote). Jotta niitä ei tarvitse asennuksen jälkeen uudestaan luoda, kopioi talteen seuraavan polun sisältämät tiedostot.~/.kde/share/apps/remoteview/
Lisää Kubuntun saloista jatkossa.
lauantaina, tammikuuta 12, 2008
1. Install (newest) wine
2. Install Watchtower Reader 2007
3. Open folder (hidden) ~/.wine/drive_c/windows/winsxs/
4. Create folder x86_microsoft.windows.common-controls_6595b64144ccf1df_6.0.0.0_none_deadbeef
5. Copy file: comctl32.dll
6. Using "Wine configuration", add dll-library comctl32.dll Installation
How it's working
Watchtower Readeri 2007:n asennus Kubuntuun
1. Asenna uusin Wine
2. Asenna Watchtower Reader 2007
3. Mene kansioon (piilokansio) ~/.wine/drive_c/windows/winsxs/
4. luo kansio x86_microsoft.windows.common-controls_6595b64144ccf1df_6.0.0.0_none_deadbeef
5. Kopioi tiedosto comctl32.dll äsken luotuun kansioon.
6. Lisää dll kirjasto winecfg:ssä ks. ensimmäistä kuvaa.
Asennus videot löydät täältä
tiistaina, joulukuuta 25, 2007
Video siitä miten vika ilmeni
Tässä hieman siitä, miten sain vian korjattua. 1. Tarkista ovatko dbus ja hal palveluiden käynnistysjärjestykset oikein.
ls -l /etc/rc2.d/*dbus* /etc/rc2.d/*hal*
lrwxrwxrwx 1 root root 14 2007-12-22 10:31 /etc/rc2.d/S12dbus -> ../init.d/dbus
lrwxrwxrwx 1 root root 13 2007-12-22 10:31 /etc/rc2.d/S13hal -> ../init.d/hal
sudo update-rc.d -f dbus remove sudo update-rc.d -f hal remove
Itse selvisin pelkällä dbusin poistolla ja lisäyksellä.
sudo update-rc.d dbus defaults 12 20
sudo update-rc.d hal defaults 13 20
/usr/lib/hal/hald-generate-fdi-cache --force
keskiviikkona, joulukuuta 19, 2007
Testasin jälleen kerran miten windows ohjelmat asentuu Linuxissa ja miten ne toimii.
Asennus onnistu moitteetta.
Video asennuksesta
Ominaisuuksiin menemisessä sitten tuliki errori ikkunoita peräjälkeen. Samoin Validaattori ikkuna aukesi mutta ei näyttänyt mitään.
Eli Muuten ohjelma toimi päällisinpuolin. Lukuunottamatta noita erroreita.
tiistaina, joulukuuta 18, 2007
Muutama sana "Julkisen avaimen" salaustekniikasta.
PGP (tulee sanoista Pretty Good Privacy) on ohjemisto, jolla voidaan salata tiedostoja ja myös vaikkapa sähköposteja (mihin tässä ohjeessa erityisesti keskitytäänkin). Ohjelman toiminta perustuu ns. julkisen avaimen tekniikkaan, jonka avulla voidaan helposti suojata tiedostot, varmistaa että vain haluttu henkilö voi muuntaa ne selväkielisiksi, sekä varmistaa tietojen lähettäjä oikeaksi henkilöksi.
Normaalit salausmenetelmät perustuvat yleensä siihen, että tiedostoa salatessa käytetään ns. avainta, esimerkiksi numerosarjaa, sanaa tai muuta vastaavaa, avuksi muunnettaessa tiedostoa. Jotta tiedot voitaisiin sitten muuntaa takaisin normaaliin muotoon, täytyy tuo avain olla tiedossa myös salauksen purkajalla. Julkisen avaimen menetelmässä jokaisella henkilöllä on kaksi toisiinsa liittyvää avainta: ns. julkinen ja salainen avain.
Julkinen avain voi olla nimensä mukaisesti kaikkien saatavilla, salainen avain taas on vain sen omistajan tiedossa. Kun julkisella avaimella salataan tiedosto, voi salauksen purkaa vain salaisen avaimen avulla. Kun taas tiedoston salaa salaisella avaimella, voi sen purkaa jokainen, joka tietää ko. henkilön julkisen avaimen (joka siis voi olla yleisesti saatavilla esimerkiksi henkilön www-sivulla).
Näinollen, jos henkilö A haluaa lähettää B:lle salatun viestin, hän voi käydä hakemassa B:n julkisen avaimen tämän kotisivulta, salata viestin sillä, ja vain B itse voi salauksen purkaa. Jos taas B haluaa lähettää A:lle, C:lle ja D:lle viestin, ja haluaa näiden voivan olla varmoja että lähettäjä on juuri B, niin hän voi salata viestin omalla salaisella avaimellaan. Tällöin tuon viestin voi purkaa vain A:n julkisella avaimella, tätä voidaankin pitää eräänlaisena digitaalisena allekirjoituksena. PGP:ssä voi lisäksi valita, onko näin "signeerattu" viesti luettavissa myös ilman julkista avainta.
Yllättävän helposti onnistuu PGP asennus ja käyttö verrattuna Windowssiin vaikka toisin luulis.
Mutta näin se vain on.
Ensinnäkin aloitetaan siitä että asennetaan PGP linuxiin. Tähän löytyy monia työkaluja.
Esim. Konsolissa on mahdollista asentaa pgpgpg niminen työkalu.
Komento: sudo apt-get install pgpgpg
Asennus etenee seuraavasti:
Komento: sudo pgp -kg
Tätä ennen on hyvä luoda kansio pgp koti kansion alle. Komento: mkdir pgp
Myös kansiolle .gnupg on hyvä antaa täydet oikeudet, muuten joudutaan käyttämään sudo komentoa pgp -kg komennon yhteydessä.
Ainakin näin kokemus sen osoitti monen yrityksen jälkeen kun operaatio tyssäsi oikeuksien puutteeseen.
Kun avainta aletaan luomaan tapahtuu seuraavaa: (lihavoitu ja kursivoitu mitä käyttäjän pitää valita tai täyttää)
This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions. See the file COPYING for details.
gpg: avainrengas "/home/nikohal/.gnupg/secring.gpg" luotu
Valitse millaisen avaimen haluat:
(1) DSA ja ElGamal (oletus)
(2) DSA (vain allekirjoitus)
(5) RSA (vain allekirjoitus)
Valintasi? 1
DSA-avainparissa tulee olemaan 1024 bittiä.
ELG-E keys may be between 1024 and 4096 bits long.
Minkä kokoisen avaimen luodaan? (2048) 1024
Halutun avaimen koko on 1024 bittiä
Kuinka kauan avaimen tulee olla voimassa.
0 = Avain ei vanhene koskaan
<n> = Avain vanhenee n päivän kuluttua
<n>w = Avain vanhenee n viikon kuluttua
<n>m = Avain vanhenee n kuukauden kuluttua
<n>y = Avain vanhenee n vuoden kuluttua
Avain on voimassa? (0) 0
Avain ei vanhene koskaan
Onko tämä oikein? (y/N) y
You need a user ID to identify your key; the software constructs the user ID
from the Real Name, Comment and Email Address in this form:
"Heinrich Heine (Der Dichter) <heinrichh@duesseldorf.de>"
Oikea nimi: Oma Nimi
Sähköpostiosoite: oma.sahkoposti@huti.fi
Huomautus:
Valitsit seuraavan käyttäjätunnuksen:
"Oma Nimi <oma.sahkoposti@huti.fi>"
Muuta (N)imi, (H)uomautus, (S)ähköposti vai (O)k/(L)opeta? o
Tarvitset salasanan suojaamaan salaista avaintasi.
gpg: gpg-agent ei ole käytettävissä tässä istunnossa
Tarvitaan paljon satunnaislukuja. Voit suorittaa muita toimintoja
(kirjoittaa näppäimistöllä, liikuttaa hiirtä, käyttää levyjä)
alkulukujen luomisen aikana, tämä antaa satunnaislukugeneraattorille
paremmat mahdollisuudet kerätä riittävästi entropiaa.
+++++.++++++++++.++++++++++.+++++++++++++++++++++++++.+++++++++++++++++++++++++++++++++++....+++++++++++++++++++++++++..+++++.++++++++++++++++++++...............>.+++++.............................................+++++
Tarvitaan paljon satunnaislukuja. Voit suorittaa muita toimintoja
(kirjoittaa näppäimistöllä, liikuttaa hiirtä, käyttää levyjä)
alkulukujen luomisen aikana, tämä antaa satunnaislukugeneraattorille
paremmat mahdollisuudet kerätä riittävästi entropiaa.
.+++++++++++++++..++++++++++++++++++++.+++++.+++++.+++++..+++++.++++++++++++++++++++..++++++++++..++++++++++...++++++++++...++++++++++++++++++++..+++++>+++++........................................................................<.+++++>++++++++++^^^
gpg: key 040A7B9F marked as ultimately trusted
julkinen ja salainen avain on luotu ja allekirjoitettu.
gpg: tarkistetaan trustdb:tä
gpg: 3 marginal(s) needed, 1 complete(s) needed, PGP trust model
gpg: depth: 0 valid: 1 signed: 0 trust: 0-, 0q, 0n, 0m, 0f, 1u
pub 1024D/040A7B9F 2007-12-14
Key fingerprint = 2E46 93CD 59FA 9124 7730 C1E8 EDF9 154D 040A 7B9F
uid Niko Hallikainen <niko.hallikainen@fotopaja.net>
sub 1024g/99BBC6A4 2007-12-14
KGpg

Asenna myös Enigmail liitännäinen ThunderBirdiin. Liitännäinen löytyy myös lisää/poista ohjelma valikoimasta.
Luo avain seuraavan videon mukaan.
Lisää Thunderbirdissä luotu avain seuraavasti.

Kohdassa OpenPGP -> Select Key...
Aukeaa seuraava ikkuna jossa voit valita avaimen jota käytetään valitussa tilissä.
Ja sitten ei muuta kuin kokeilemaan miten pelaa.
perjantaina, marraskuuta 30, 2007
Kaverini/sukulainen mutkien kautta, harrastaa kanssa Linux testailuja. Ja eilen sitten hän jo kommentoikin että on olemassa Firefox liitännäinen jolla saa videot näkymään kokoruudun kokoisena. Ja sitten piti itsekkin testata sitä ja todeta että se toimii.
Plugnin saat ladattua täältä
Configurointi esimerkki video.

Testissä näkyy, miten netti-tv toimii.
Ensinnä Nelonen, Yle:n Elävä arkisto, ja viimeisenä osittain toimiva mtv3 sivusto.
Seuraavassa Yle:n uutiset netti-TV:ssä
Firefox kaatu mtv3 testin aikana!
Eilen vielä toimi mutta tänään olikin oikukkaalla päällä.
torstaina, marraskuuta 29, 2007
Vähän testiä miten ne toimii ja miten säädät toimimaan omalla koneellasi.
Mutta ensin testeihin:
Ensin testaamme Neloset Netti-TV:tä. Suoraan selaimessa se ei toimi ollenkaan. Kun tekee testin, ilmoittaa että vaaditaan Windows XP sun muuta.

Jonka pystyy toistamaan sitten linuxissa jossain videon katselu ohjelmassa. Kokeilin itselläni Totem soitinta ja video latautui ja näkyi tökkimättä.
Tässä kuvassa näkyy miten nelosen video toimii totemissa.
Seuraavaksi tulilinjalle joutui MTV3:n netti-TV.
Mtv3:n netti TV näyttää toimivan moitteetta, tosin pieniä miinuksia siitäkin löytyy. Esim. mainokset kun latautuu siihen menee aikaa ja xine bufferoi monesti ja pitkään kunnes video tulee näkyviin. Ensimmäisenä näkyy työkkärin mainos. Sitte alkaa se bufferointi :).
Kokeilin kolmea eri plugina Firefoxissa. Ja parhaaksi ja toimivaksi osoittautui xine-plugin. VLC-plugin ei näyttänyt mitään. mplayer-plugin bufferoi ja heitti mystisen errorin, eli vain teksin että buffering ja videota ei näy.
Aikaisemmin kirjotinkin miten saa kaikki toimimaan koneella DVD:t yms... Mutta netti-tv toimii xine-pluginilla parhaiten tällä hetkellä.
Tässä esimerkki miten toimii mtv3 netti-TV
Kannattaa tutustua aikaisempaan kirjoitelmaan. Löydät ne täältä.
Täältä löytyy lisää testi matskua.
keskiviikkona, marraskuuta 28, 2007
KDE 4 RC1
Vielä pientä hiomista vaille valmis. Ensi vaikutelma todella hyvä. Muutamia bugeja vielä. Mutta hyvässä suunnassa mennään.
Tässä hieman ohjeita miten saat asennettua sen Kubuntuun.
Lisää KDE:stä täällä blogissa -> siirry blogiin (Juhani Matilainen, Linux Guru)
Käynnistä Adept Manager
Lisää latauslistaan konsolissa komennolla: sudo kate /etc/apt/sources.list
Tämä rivi alimmaksi: deb http://ppa.launchpad.net/tsimpson/ubuntu gutsy main
Asenna seuraavat paketit:
kdebase-dev-kde4
kdebase-workspace-dev
kdebase-runtime
kdm-kde4
Lisää komennolla sudo kate /usr/lib/kde4/bin/startkde tiedoston alkuun seuraavat rivit.
export LD_LIBRARY_PATH=/usr/lib/kde4/lib
export KDEDIRS=/usr/lib/kde4
export PATH=/usr/lib/kde4/bin/:$PATH
export KDEHOME=~/.kde4
Kopioi seuraavaksi kde.desktop toiseen toiseen paikkaan nimellä kde4.desktop.
Eli konsolissa komento: cd /usr/lib/kde4/share/kde4/apps/kdm/sessions/
Ja tuolla kansiossa on kde.desktop tiedosto.
Kopioi se komennolla: sudo cp kde.desktop /usr/share/xsessions/kde4.desktop
Sitten palaa kansioon /usr/share/xsessions/.
Komento: cd /usr/share/xsessions/
Muokkaa tiedostoa kde4.desktop komennolla: sudo kate kde4.desktop
Muokkaa riviä Name=KDE lisää perään kuten kuvassa 4. Ja nyt vain kokeilemaan.
Kirjaudu ulos ja valikosta voit valita mitä käytät joko KDE tai KDE4
Tai jos haluat kokeilla livecd:llä sekin on mahdollista ;) ihan näin lopuksi mainitsen sen.
Live-cd:n saa täältä.
maanantaina, marraskuuta 26, 2007
Lataa VMwaren sivuilta gz paketti. Asennuksessa käytin uusinta versiota eli VMware-player-2.0.2-59824.
Tai täältä.
Ensin pitää vain purkaa kotikansioon tai mihin hyvänsä tämän lataamasi paketin sisältö.
vmware-player-distrib kansiossa on tiedosto: vmware-install.pl, jolla asennus suoritetaan.
Asennus tapahtuu konsolissa komennolla: sudo ./vmware-install.pl.
Seuraavassa ote mitä asennuksen aikana tapahtuu löytyy ladattavasta tiedosta.
Ensimmäisen käynnistyksen aikana kysellään lisenssi hyväksymiset.
Skype säätöä
Vielä Skypen hymiö asiaa ihmettelin tässä tänään kun ne eivät ole animoituja. Ja ratkasu löyty oleellisesti asetuksista. :)
Eli Options -> Chat -> ja ruksi ruutuun "Show animated emoticons".
lauantaina, marraskuuta 24, 2007
Aikaisemmin tunnettu Ifi jossa sai netin kautta tilattua kuvat postitse kotiin muutti nimeään. Ja samoin ohjelma on vain Windows versio. Joten päätin kokeilla miten se taipuisi Kubuntussa winen avulla. Ensin näytti hyvältä mutta asennus vaati IE:n jonkin version joko 5.5 tai uudemman. Tämähän sotii kaikkia Linux käyttäjien periaatteita vastaan IE linuxissa :D.
Mutta päätin kokeilla tulevasta kritiikistä huolimatta. Joten asensin IE 6:n. Ja sehän meni heittämällä vaikkei uskoisi.
Video IE asennuksesta
Tämän jälkeen siirryin sitten toiseen vaiheeseen asentamaan tilausohjelmaa winen avulla.
Video siitä
Ja uskomatonta sehän toimii, mutta silti jäi vaivaamaan tämä asia miksi tällainen ohjelma tarvitsee IE:tä :) toimiakseen/asentuakseen??
Video miten ifolor toimii
Ie6.exe
Ifolor.exe
Vielä pientä lisäystä tähän ohjelmaan. Muuten toimi mutta kuvien lähettäminen ei onnistunut, ja tähän varmaan liittyi tämä IE :). Ja kuvien valinnassa, kun oli valittuna kuva ei näkynyt niemä ja kuvan koko ja paperin laatua millaiseksi se sitten teetetään.
Video toiminnasta
torstaina, marraskuuta 22, 2007
Ensinnäkin tulee olla siinä kansiossa jossa kyseinen paketti on.
Sitten vain komento: sudo dpkg -i paketin_nimi.deb
Tätä usein tarvitaan jos graafinen deb pakettien asennus ohjelma kaatuu ilman näkyvää syytä.
Taulukko dpkg:n optioneista.
| Option | Kuvaus mitä tekee |
| -i | Paketin asennus. |
| -r | Paketin poistaminen (-P tai --purge poistaa myös asennustiedostot). |
| -l | less | Asennettujen pakettien listaus (perässä less koska paketteja yleensä enemmän kuin yksi ruudullinen. |
| -L | Paketin tiedostojen listaaminen. |
| -s | Asennetun paketin tiedot. |
| -S | Tiedoston etsiminen asennetuista paketeista. Tiedostonimenä voidaan käyttää myös nimen osaa. |
Asennus paketti voidaan pakottamalla asentaa käyttämällä seuraavaa komentoa.
Tätä kannattaa käyttää kun tiedät mitä teet. Esim. asentaa vanhempi versio jostain ohjelmasta koneelle joka ei muuten suostu ja onnistu asentaa.
Ohessa taulukko muutamista komennoista.
| --force-downgrade -i [paketin nimi] | Vanhempi versio |
| --force-overwrite -i [paketin nimi] | muissa paketeissa olevien tiedostojen korvaaminen |
| --force-depends -i [paketin nimi] | Riippuvuusongelmista huolimatta asennetaan |
| --force-architecture -i [paketin nimi] | Asennetaan paketti vaikka arkkitehtuuri ei täsmää. |
| --force-help | Lisäohjeita pakottamisesta |
--force:a ennen tulee dpkg.
Eiliseen pientä jatko tässä. Mm. komennoista joita siinä oli.
Taulukko komennoista moduulien käsittelyyn
| Ohjelma | Kuvaus mitä tekee |
| lsmod | Listaa järjestelmään ladatut moduulit. |
| insmod | Liittää moduulin aktiiviseen kerneliin |
| modprobe | Lataa yhden tai useamman moduulin ja niiden tarvitsemat lisämoduulit |
| depmod | Luo tiedoston, jossa on moduulin käytössä (modprobe) tarvittavat lisämoduulit. |
| rmmod | Poistaa tällä hetkellä ladattuna olevat moduulit ytimestä. |
grep [optiot] merkkijono [tiedosto(t)]
grep-komennolla haetaan merkkijonoa tai merkkijonomallia tiedostosta. grep-komennossa merkkijonomalli voi olla säännönmukainen lauseke.
Grep-komennon optiot seuraavassa taulukossa
| -c | Tulostaa rivien lukumäärän |
| -f [tiedosto] | Käyttää haettavina merkkijonoina tiedostossa olevia sanoja. |
| -i | Isot ja pienet kirjaimet samaistetaan (igore case) |
| -n | Hakee rivit rivinumeroineen |
| -v | Hakee rivit, jotka eivät vastaa haettavaa merkkijonoa |
| -w | Hakee täysin haettavaa merkkijonoa vastaavaa sanaa. Muten grep etsii ko. merkkijonon sisältävät sanat. Sana on merkkijono, jonka molemmilla puolilla on jokin tyhjämerkki (välilyönti, tabulaattori tai rivinvaihto) |
Kun tämä dmesg-komento tulostaa viimeisimmät ytimen viestit, mm ne jotka näkyvät käynnistyksessä. Ja grep hakee kaikki missä on pnp.
Näin kätevää on linuxin vikoje ja ongelmien selvitteleminen.
keskiviikkona, marraskuuta 21, 2007
Vanha ISA Creativen Vibra16c kortti oli kyseessä. Eka vaikutelma kun kortti ei tunnistaudu ollenkaan Linuxissa, että kortti on sökö tai että ei vain muuten toimi.
Tässä tapauksessa oli kyseessä tuo viimeinen vaihtoehto, eli vaati hieman säätö jotta äänet lähtee toimimaan.
Eli ensin konsolissa komento: dmesg | grep pnp
Tämä tulostaa seuraavankaltaisen listan:
[ 23.760586] pnp: PnP ACPI init
[ 23.760631] ACPI: bus type pnp registered
[ 23.771596] pnp: PnP ACPI: found 12 devices
[ 23.771610] ACPI: ACPI bus type pnp unregistered
[ 23.773406] pnp: 00:00: iomem range 0xf0000-0xf3fff could not be reserved
[ 23.773424] pnp: 00:00: iomem range 0xf4000-0xf7fff could not be reserved
[ 23.773438] pnp: 00:00: iomem range 0xf8000-0xfbfff could not be reserved
[ 23.773452] pnp: 00:00: iomem range 0xfc000-0xfffff could not be reserved
[ 26.530556] isapnp: Scanning for PnP cards...
[ 26.678970] pnp: SB audio device quirk - increasing port range
[ 26.694157] isapnp: Card 'Creative ViBRA16C PnP'
[ 26.694170] isapnp: Card 'U.S. Robotics Sportster 33600 FAX/Voice Int'
[ 26.694182] isapnp: 2 Plug & Play cards detected total
[ 26.902873] pnp: Device 01:02.00 activated.
[ 39.736000] pnp: Device 01:01.01 activated.
[ 39.752000] gameport: NS558 PnP Gameport is pnp01:01.01/gameport0, io 0x200, speed 736kHz
Mutta seuraavassa bootissa se lakkaa toimimasta, joten muokkaa seuraavaa tiedostoa seuraavasti.
sudo kate /etc/modules
Lisää viimeiseksi rivi: snd-sb16
Sitten vain tallennus ja bootti.
Linux puolen versio oli hieman pettymys. Tästä siis pisteitä ropsahtaa pois. Sillä ohjelma on melkein sama kuin mikä Windowssille ja ajetaan Winen päällä. Alla muutama kuva siitä mitä eroja.
Linux version säädöt.
Windows version säädöt
Kyseisen projektin sivu löytyy täältä
Lyhyt video miten toimii Kubuntussa
maanantaina, marraskuuta 19, 2007
Tästä on voinut olla jo aiemmin juttua, mutta uusimmassa versiossa eli Gutsy:ssä puuttuvat kodecit saa asennettua Adeptilla.
Etsi ubuntu-restricted-extras paketti ja asenna se mikäli puuttuu.
Lista mitä asentaa.
- libxine-extracodecs
- libarts1-mpeglib
- libarts1-xine
- libakode2-mpeg
- w32codecs
Asenna ensin paketit:
- libdvdread3
- libdvdplay0
- libdvdnav4
DMA-tuki
Jos tämä on poissa päältä elokuvat nykii.
Joten aja konsolissa komento: sudo kate /etc/hdparm.conf
Ja lisää viimeiseksi rivi:
/dev/cdrom { |
Java asennuksessa saattaa tulla mutkia matkaan, ainakin minulle kävi niin. Ja muistelen että tämä samainen bugi on ollut jo pitkään. Eli kun asennat Java-jre ja bin pakettia tee se konsolissa. Adept ei osaa toistaiseksi lisenssi hyväksymis ikkunaa käyttää tai se toimii mutta menee jotenkin jumiin jne...
Mutta jos adep on sen ladannut, niin se konfaus ei sitten toimi.
Ensin kannattaa ajaa komento: sudo dpkg --configure -a
Ja tämän jälkeen: sudo apt-get -f install
Tässä video mitä tapahtuu näiden avulla.
keskiviikkona, marraskuuta 14, 2007
Koko ajatus saattaa tuntua hirveältä ja kuullostaa vaikealta. Mutta näin asia kuitenkaan ei ole.
Ensinnäkin konsolissa tehdään seuraava
$ hcitool scan
Tämän komennon pitäisi palauttaa seuraavaa:
esim. 00:15:A0:7A:1D:5A Noksu N73
Eli puhelimesi mac osoite.
Sitten seuraavassa komennossa käytä oman puhelimesi mac osoitetta
Ja tällä komennolla selvitämme mitä kanavaa kännykän modeemi(RFCOMM) käyttää.
$ sdptool browse 00:15:A0:7A:1D:5A
Tämä tulostaa ehkä valtavan listan kaikista mitä kanavia puhelimessa on.
Mutta etsi sen kaiken joukosta otsikko jossa lukee Service Name: Dial-Up Networking
Eli lista näyttää tältä suurinpiirtein:
Service RecHandle: 0x1000f
Service Class ID List:
"Dialup Networking" (0x1103)
Protocol Descriptor List:
"L2CAP" (0x0100)
"RFCOMM" (0x0003)
Channel: 2
Language Base Attr List:
code_ISO639: 0x454e
encoding: 0x6a
base_offset: 0x100
Profile Descriptor List:
"Dialup Networking" (0x1103)
Version: 0x0100
Eli kanava 2 tässä tapauksessa, omassa puhelimessasi se voi olla joku muu.
Muokkaa tiedosto rfcomm.conf vastaavaksi tämän kanssa.
Komento: sudo kate /etc/bluetooth/rfcomm.conf
# Automatically bind the device at startup
bind yes;
#
# # Puhelimen mac-osoite
device 00:15:A0:7A:1D:5A;
#
# # RFCOMM kanava
channel 2;
#
# # Description of the connection
comment "Noksu N73";
}
Sitten enää puuttuu vain yhteys astukset.
Esimerkkinä Elisan asetukset:
Luo tiedosto komennolla: sudo kate /etc/ppp/peers/elisa
Ja muokkaa se seuraavan kaltaiseksi
# Most GPRS phones don't reply to LCP echo'sJa sitten seuraavanlainen tiedosto kuin elisa-connect-chat komennolla: sudo kate /etc/ppp/elisa-connect-chat
lcp-echo-failure 0
lcp-echo-interval 0
# Keep pppd attached to the terminal:
# Comment this to get daemon mode pppd
nodetach
# Debug info from pppd:
# Comment this off, if you don't need more info
debug
# Show password in debug messages
show-password
# Connect script:
# scripts to initialize the GPRS modem and start the connection,
connect /etc/ppp/elisa-connect-chat
# Disconnect script:
# AT commands used to 'hangup' the GPRS connection.
disconnect /etc/ppp/elisa-disconnect-chat
# Serial device to which the GPRS phone is connected:
#/dev/ttyUSB0 # USB
#/dev/ttyACM0 # Data cable device file
/dev/rfcomm0 # Bluetooth device file
# Serial port line speed
115200 # fast enough
#57600
# Hardware flow control:
# Use hardware flow control with cable, Bluetooth and USB but not with IrDA.
crtscts # serial cable, Bluetooth and USB, on some occations with IrDA too
#nocrtscts # IrDA
# Ignore carrier detect signal from the modem:
local
# IP addresses:
# - accept peers idea of our local address and set address peer as 10.0.0.1
# (any address would do, since IPCP gives 0.0.0.0 to it)
# - if you use the 10. network at home or something and pppd rejects it,
# change the address to something else
0.0.0.0:0.0.0.0
# pppd must not propose any IP address to the peer!
noipdefault
# Accept peers idea of our local address
ipcp-accept-local
# Add the ppp interface as default route to the IP routing table
defaultroute
# DNS servers from the phone:
# some phones support this, some don't.
usepeerdns
# ppp compression:
# ppp compression may be used between the phone and the pppd, but the
# serial connection is usually not the bottleneck in GPRS, so the
# compression is useless (and with some phones need to disabled before
# the LCP negotiations succeed).
novj
nobsdcomp
novjccomp
nopcomp
noaccomp
noccp
# The phone is not required to authenticate:
noauth
# Username and password:
# If username and password are required by the APN, put here the username
# and put the username-password combination to the secrets file:
# /etc/ppp/pap-secrets for PAP and /etc/ppp/chap-secrets for CHAP
# authentication. See pppd man pages for details.
user "rlnet"
password "internet"
#
mtu 1500
mru 1500
asyncmap 0xa0000
Seuraavalla sisällöllä:
#!/bin/sh |
Ja vielä yksi tiedosto komennolla: sudo kate /etc/ppp/elisa-disconnect-chat
Seuraavalla sisällöllä:
#!/bin/sh |
Ja yhteys luodaan komennolla: pon elisa
Ja ei muutakuin surffailemaan
maanantaina, marraskuuta 12, 2007
1. Install (newest) wine
2. Install Watchtower Reader
3. Open folder (hidden) ~/.wine/drive_c/windows/winsxs/
4. Create folder x86_microsoft.windows.common-controls_6595b64144ccf1df_6.0.0.0_none_deadbeef
6. Using "Wine configuration", add dll-library comctl32.dll
7. Extract fonts.zip and copy files into the following folder: ~/.wine/drive_c/windows/fonts/
This video shows how WTReader works between different languages. (Works fine with VLC-player)
More tips.
lauantaina, marraskuuta 10, 2007
Omistan monitoimilaitteen HP 3052 LaserJetin. Laite toimii verkonläpi. Asennus ubuntuu oli helpompi kuin XP:ssä ja tämähän on positiivinen asia.
(Kuvat saa suuremmaksi klikkaamalla niitä)
Ensinnäkin osasi hakea automaattisesti laitteen verkonkautta.
Sitten vain kokeilemaan miten laite toimii.
Oheisissa kuvissa vastaus:
Oli ensinnäkin valittava laite jolla kuva luetaan, eli joko web kamera vaiko ihan skanneri.
Skannattavana sivuna käytin testitulostuksessa tullutta sivua. Joten kaikki pelaa kuten pitääkin. Ja plussaa vielä siitä että nopeemmin kuin XP:ssä.
Nähtävästi Ubuntun asennuksen aikana on jo nuuskittu mitä laitteita koneeseen on liitetty jopa verkonläpi, tästä en ole varma mutta tästä olen varma että ei sattumalta HPLIP Toolbox löydy tältä koneelta.
Pieni video
Asennus video
Wubi toimimaan. Jos asennuksen aikana ilmenee että asennus ohjelma ilmoittaa väärää käyttäjänimeä ja salasanaa. Oheisesta ohjeesta saattaa olla apua tässä tapauksessa.
Koska yleensä XP:n asennuksessa käyttäjä nimi on muodossa Nimi Sukunimi. Joten wubi kansiosta löytyy install kansio, jossa on tiedosto preseed.cfg. Melkein lopussa on oheinen kohta.
Laita kaikkiin kohtiin risuaita # eteen jolloin oheista toimitoa ei suoriteta asennuksen aikana eli XP profiilin tuonti ubuntu ympäristöön.
## MIGRATION-ASSISTANT
#UserFolder=/Documents and Settings/Niko Hallikainen
# d-i preseed/early_command string anna-install migration-assistant
# d-i migration-assistant/partitions multiselect Windows XP Professional (/dev/MADEVICE)
# d-i migration-assistant/MADEVICE/users multiselect Niko Hallikainen
# d-i migration-assistant/MADEVICE/Niko Hallikainen/items multiselect AIM Triton, Internet Explorer, Yahoo, MSN, Opera, Firefox, Wallpaper, User Picture, Outlook Express, Gaim
# d-i migration-assistant/MADEVICE/hostuser/items multiselect My Documents, Internet Explorer
# d-i migration-assistant/MADEVICE/Niko Hallikainen/user string nikohallikainen
# d-i migration-assistant/new-user/linuser/password password xyz
# d-i migration-assistant/new-user/linuser/password-again password xyz
# d-i migration-assistant/new-user/linuser/fullname string fullusername
# d-i migration-assistant/new-user/linuser/administrator boolean true
Viimesin versio wubista on ladattavissa wubin sivuilta.
keskiviikkona, kesäkuuta 27, 2007
Enemmän aiheesta tässä blogissa
Täällä vanhempi ubuntu asennus.exe.
Koko versio (617mb).
Asennus ohjeet.
Uudempi asennus paketti.
Wubista muutava vinkki!
Kun olet ladannut sen, niin lataa myös haluamasi distro isona. Eli esim. kubuntu.
Ison löydät täältä (torrent) tai iso
Luo asennus levyn juureen kansio wubi-save ja kopioi sinne lataamasi iso.
Näin säästät aikaa asennuksessa, koska muutoin ohjelma lataa sen asennuksen aikana. Mutta jos olet jo ladannut sen aiemmin, niin ei muuta kuin kopsaat vain hakemistoon ja testaat.
Sitten ihan muutama asia miten kävi minulle tämän asennuksen kanssa.
Ensimmäisellä kerralla asennus tyssähti siihen että tuli ilmoitus väärästä käyttäjänimsetä. Toisella kerralla valittikin asennus media virheellisyydestä vaikka se oli kunnossa koska asennusa ohjelma testaa sen ennen asennusta. Eli vielä en ole saanut sitä täysin toimimaan.
torstaina, huhtikuuta 19, 2007
Kaikki alkoi siitä että tila loppui juuri osiolla. Ja halusin vähän saada lisää tilaa luomalla uuden tyhjän osion ja mountaamalla se Linuxiin.
Jollain keinoin tässä rytäkässä meni kone täysin jumiin ja kuten jälkeen päin huomasin pelastus operaatioissa, että fstab tiedosto oli mennyt täysin sekaisin. Mutta lisää ongelmia oli tulossa. Sillä grub lataaja ei suostunut toimimaan vähän ajan päästä. XP niin sanotusti pyyhki sen pois.
Kuva vielä siltä ajalta jolloin Grub toimi.
Isompi kuva tästä.
Kun sain sen fstabin korjattua, edessä oli Grubin korjaus. :)
Hirvittääkö?? Minua ei ainakaan enää!
Grubin sain asennettua ja se tulikin näkyviin joka bootin aikana, mutta olikin jo toinen ongelma edessä. Vaikka kernelin valinta onnistui ei se vain lähtenyt käyntiin, vaan tuli ilmoitus "".
Sitten vain vielä syvemmälle Grubin syövereihin ja editoimaan suoraan menu.lst :).
Jouduin muuttamaan arvon (hd0,7) arvoksi (hd0,6). Ja vola se lähti kuin lähti käyntiin :)
Mutta ehdottomasti yksi suosikki on tästä lähtien "systemrescuecd".
Ubuntu versiona oli Feisty beta, joten ei ihme jos jokin ei toimi kuten pitää.
Mutta tässä voi oppia sen, että ei kannata luovuttaa vaikka näyttikin aika epätoivoselta se tilanne.
keskiviikkona, huhtikuuta 18, 2007
Tässä eräs hyödyllinen ohjelma, jos käy niin että Linux sanoo ittensä irti ja pitäisi saada tiedostoja talteen.
Tällä työkalulla se onnistuu "Ext2 Installable File System for Windows".
Tietenkin toisinkin päin se onnistuu. Nykyisin Ubuntussa tulee mukana hyvä NTFS levy työkalu jolla voi lukea ja kirjoittaa NTFS levylle. Että pisteet siitä kehityksestä Linux kehittäjille :)
Tässä kasattuna pika ohje miten saa Linuxin käynnistymään boot.ini:stä.
dd if=/dev/hda5 of=boot.lnx bs=512 count=1
Huom. Tulee ajaa äskeinen komento Root oikeuksilla.
hda5 on se osio jossa on /boot kansio
Voit tarkistaa sen komennolla df, mikä on sinun hda#
Sitten kopioi boot.lnx levykkeelle.
mcopy boot.lnx a:
Kun olet käynnistänyt XP:n tai Windows 2000:n.
Editoi boot.ini tiedostoa. Ota luku- oikeudet pois tiedostosta, jotta voit muuttaa sitä.
Lisää viimeiseksi rivi:
c:boot.lnx="Ubuntu Linux"
Ja laita luku- oikeudet takaisin jotta se toimii. Ja kopioi levykkeeltä boot.lnx C:n juureen.
Ensin tietenkin levyaseman mountaus.
Menet hakemistoon cd /usr/lib/grub/i386-pc
Sitten vain komennot
dd if=stage1 of=/dev/fd0 bs=512 count=1
dd if=stage2 of=/dev/fd0 bs=512 seek=1
Ja levykkeen pitäisi toimia.
Malli video
tiistaina, huhtikuuta 17, 2007
Tarvitset kaksi asiaa:
- Bootti imagen jonka löydät Ubuntu asennus levyltä kansiosta install (sbm.bin)
- NTRawrite
NtRawriten saat ladattua sourceforgen sivuilta.
Tai täältä.
Kopioi kaikki samaan kansioon ja suorita seuraava komento: ntrawrite -f sbm.bin -d a:
Sitten vain odotat että bootti levyke valmistuu.
lauantaina, huhtikuuta 07, 2007
Google Earth asennus linuxiin
Ensin tulee antaa suoritus oikeudet asennus paketille.
chmod +x G*.bin
Asennus tapahtuu komennolla ./GoogleEarthLinux.bin
Asennuksen aikana tulevat tekstit.
Verifying archive integrity... All good.
Uncompressing Google Earth for GNU/Linux 4.0.2735.0..................................................................
Installing mimetypes...
Running /usr/bin/update-mime-database /home/niko/.local/share/mime
Installing desktop menu entries...
Alla näkyy kuvista miltä asennus näyttää... Joudut vastaamaan muutamaan kysymykseen.
Sitten vain odotat että asennus menee loppuun.
Ja sitten vain star niin ohjelma käynnistyy.
Picassan asennus Linuxiin
http://picasa.google.com/linux/thanks-deb.html englanniksi.
Molemmat ohjelmat voi ladata suoraan googlelta tai sitten http://nikohallikainen.pp.fi/blogi/linux
perjantaina, huhtikuuta 06, 2007
Gnomessa, jos haluat asentaa KDE työpöytä ympäristön.
komento: sudo apt-get install kubuntu-desktop
Tähän tulee vielä lisää saman kaltaisia ajan kanssa :)
tiistaina, tammikuuta 30, 2007
Ihan näin tietona että kaikki ladattavat lisämateriaalit mitä on aiemmin ollut blogeissani, eivät enää välttämättä ladautu. joten olen siirtänyt ne uuteen ja tilavampaan paikkaan. Vanhojen linkkien päivitystä teen mikäli aika sallii, mutta blogien ladattavat tiedostot löytyy tästä lähtien osoitteesta http://nikohallikainen.pp.fi/blogi/ ja vastaavasti edelliseen kaspersky ongelma blogiin löytyy osoitteesta http://nikohallikainen.pp.fi/kaspersky/ .
maanantaina, joulukuuta 11, 2006
Ohjelma versio: 5.0.225
Käyttöjärjestelmä: Windows XP Pro (FIN)
Ohjelma jossa ongelma ilmenee Kasperskyn takia: Office 2003 Pro (FIN)
Ongelma: Kun Kaspersky anti-virus ohjema on "Enable Real-Time Protection" asetuksella, niin ilmenee seuraavanlainen ongelma.
Kaikki ohjatut toiminnot Access ohjelmassa muuttuvat englanniksi. Ja ainoastaan taulukon luonti toimii jotenkin. Mutta muissa ohjatuissa toiminnoissa ei toimi mikään. Ja jotkin virhe ilmoitukset tulevat myös englanniksi, vaikka kyseinen Office paketti on suomen kielinen.
Jos Kasperskyn laittaa "Disable Real-Time Protection" asetuksen, niin ohjelma toimii normaalisti. Kaikki ohjatut toiminnot toimivat suomen kielellä. Eli jotenkin reali-aikainen tarkistus sotkee ohjelman toimivuuden.
Ongelma koskee myös uudempaa Kaspersky 5.0.712. Mutta vanhemmassa 4.5 versiossa kaikki toimi normaalisti.
Lisä materiaalia ohjelman toimivuudesta löytyy videon muodossa ja flash tiedosto muodossa.
Video1
Flash1
Video2
Flash2
Video ja saman numeroinen flash sisältävät saman asian.
Kuvassa Ohjattu taulukon luominen, osittain suomeksi ja osittain englanniksi.
Kuvassa Ohjattu lomakkeen luominen, osittain suomeksi ja osittain englanniksi ja ei anna Taulukon kenttä tietoja esiin.
Kuvassa Ohjattu raportin luominen, osittain suomeksi ja osittain englanniksi, ja ei anna taulukon kenttä tietoja.
perjantaina, joulukuuta 08, 2006
Lähde ym. olennainen on mainittuna.
Tarkoitus oli hieman lisätä omia ajatuksia joukkoon, mutta ajan puutteen takia en sitä vielä tehnyt vaan julkaisin sen tällaisena.
keskiviikkona 8.11.2006 klo 10:55
Novell tienaa yli 300 miljoonaa dollaria
Microsoft-Linux-sopimuksen jättisummat paljastuivat
Microsoftin ja Novellin yllättävän Linux-yhteistyön taloudelliset yksityiskohdat ovat paljastuneet, ja Microsoft onkin satojen miljoonien dollarien maksumiehenä. Tämä on yllättävää, sillä yhtiön täytyi lähinnä myöntyä Linux-yhteistyöhön, mutta Microsoftin mukaan syynä onkin uusi hittitekniikka virtualisointi.
Sopimuksen taloudelliset yksityiskohdat paljastuivat, kun Novell jätti pakollisia selvityksiä Yhdysvaltojen rahoitusviranomaisille.
Microsoft ostaa 240 miljoonalla Linux-tukea asiakkailleen
SEC:lle toimitetussa selvityksessä kerrotaan, että Microsoft ostaa Novellilta 240 miljoonan euron edestä tukipalveluita. Microsoft hankkii summalla Novellilta yhteensä 350 000 "tukikuponkia", joita se voi jakaa asiakkailleen. Tukea ostetaan 70 000 ainakin kupongin vuosivauhdilla.
"Pääsyy tähän on mahdollistaa meidän oman virtualisointiratkaisumme tuominen markkinoille", selvittää aluksi yllättävältä kuulostavaa sopimusta Microsoftin päälakimies Brad Smith uutispalvelu Cnetille.
Virtualisoinnissa samalla palvelimella ajetaan rinnakkain esimerkiksi Windowsia ja Linuxia. Microsoft haluaa laajentua tällä palvelinmaailman kuumalla alueella, mutta ilman kunnollisia tukipalveluita se ei onnistu.
108 miljoonalla patentteja, 94 miljoonalla myyntitukea Linuxille
Microsoftin ja Novellin sopimukseen liittyy myös 108 miljoonan dollarin maksu Microsoftilta Novellille. Sillä kuitataan yhtiöiden aikaisempia patenttiriitoja, mutta ei kaikkia menneitä monopolioikeusriitoja.
Toisaalta Novell maksaa Microsoftille 40 miljoonaa dollaria siitä, että Microsoft ei haasta oikeuteen Novellin asiakkaita mahdollisista patenttirikkeistä, kertoo Cnet.
Yhteensä rahaa liikkuu siis Microsoftilta Novellille 308 miljoonaa dollaria. Tämän lisäksi Microsoft lupautuu käyttämään 94 miljoonaa dollaria seuraavan viiden vuoden aikana Novellin Suse Linux -tuotteiden markkinointiin ja myyntiin. Microsoftin sitoumus on siis yhteensä 402 miljoonaa dollaria.
tiistaina 21.11.2006 klo 12:08
Onko Microsoftilla patentteja Linux-tekniikoihin?
Novell ja Microsoft riitelevät Linux-patenteista
Novellin ja Microsoftin pääjohtajat ovat joutuneet julkiseen erimielisyyteen Linuxin patenttitilanteesta. Steve Ballmer sanoo, että Linux rikkoo Microsoftin patentteja, mutta Novellin pääjohtaja tyrmää tämän avoimessa kirjeessään.
Microsoft ja Novell solmivat hiljattain yllättäen sopimuksen, jonka nojalla yritykset aloittavat yhteistyön Linuxin tiimoilta. Sopimuksen perusidea oli rakentaa asiakkaille parempia työkaluja, joilla Linux- ja Windows-palvelimet toimivat paremmin yhteen.
Ballmer: Linux rikkoo patenttejamme
Microsoftin Steve Ballmer on esittänyt julkisuudessa myös toisenlaista viestiä. Hänen mukaansa asiakkaat tarvitsivat myös suojaa Linuxin patenttiongelmia vastaan. Ballmerin mielestä Microsoftin patentit kattavat myös Linuxin tekniikoita, joten Novell-Microsoft-sopimuksen patenttisuoja on myös tärkeä osa asiakkaiden saamaa hyötyä.
Novellin on väitetty käytännössä vahvistaneen tämän, kun se solmi patenttisuojasopimuksen Microsoftin kanssa. Kun spekulaatiot asiasta kasvoivat, päätti Novellin pääjohtaja julkistaa asiasta avoimen kirjeen.
Ron Hovsepianin mukaan Novell ei missään nimessä myöntänyt Linuxin patenttihuolia, eikä ole samaa mieltä asiasta Microsoftin kanssa. Novell ei ole asiassa vaarassa sopimuksen vuoksi, mutta esimerkiksi Red Hat ja muut Linux-talot periaatteessa ovat.
Ballmer: Linux loukkaa Microsoftin immateriaalioikeuksia
Microsoftin toimitusjohtaja Steve Ballmer totesi torstaina Professional Association for SQL Server -konferenssissa Seattlessa viime torstaina, että hän uskoo Linuxin loukkaavan Microsoftin immateriaalioikeuksia. Ballmer mainitsi asiasta keynote-puheensa jälkeisessä kysymys ja vastaus -sessiossa. Ballmerin mukaan osasyy Microsoftin ja SUSE Linuxin jakelijan Novellin aiemmin marraskuussa solmimalle sopimukselle oli se, että Linux luokkaa Microsoftin immateriaalioikeuksia.
Marraskuun toisena päivänä solmitussa sopimuksessa yhtiöt lupautuivat parantamaan Linuxin ja Windowsin yhteensopivuutta. Lisäksi Microsoft maksaa Novellille omille asiakkailleen tarjottavasta Linux-tuesta. Immateriaalioikeuksista puhutaan myös, sillä Novell maksaa sopimuksen mukaan Microsoftille 40 miljoonaa dollaria siitä, ettei Microsoft vedä sitä oikeukteen mahdollisista patenttiloukkauksista. Sopimus suojaa kaikki yksilöt ja ei-kaupalliset avoimen lähdekoodin tekijät, joiden koodia päätyy SUSE Linuxiin.
Sopimuksen tekohetkellä Microsoft ei paljastanut sen tarkemmin, mistä asiassa oli oikeastaan kyse. Useat avoimen lähdekoodin puolesta puhujat sen sijaan kritisoivat sopimusta äänekkäästi. Viime torstaina Ballmer oli kuitenkin avoimempi. "Novell maksaa meille rahaa, jotta jokainen SUSE Linuxin käyttäjä tietää ohjelmiston käytön olevan laillista", Ballmer sanoi. "Tämä on meille tärkeää, sillä muuten jokainen Linuxin käyttäjä olisi mielestämme meille velkaa", hän jatkoi.
Ballmerin puheita ei ole nielty aivan sellaisenaan Linux-yhteisössä. "Emme usko, että Microsoftin ja Novellin sopimuksessa määritellylle korvaukselle on minkäänlaista tarvetta tai perustetta", totesi Red Hatin asianajaja Mark Webbink. Red Hat väittää pystyvänsä suojelemaan omat asiakkaansa patenttiloukkaussyytöksiltä. Lue juttu.
Postittanut K2, 21.11.2006, kello 01:10. Lähde: LinuxWorld
Linux-aktiivit muuttamassa lisenssiehtoja Microsoftin pelossa
Marko Mannila
Julkaistu 22.11.2006 kello: 07:50
Linux-aktiivit ovat muuttamassa käyttöjärjestelmän lisenssiehtoja Microsoftin ja Novellin sopimuksen vuoksi.
Microsoft solmi hiljattain sopimuksen Novellin kanssa. Sopimuksen mukaan Novell maksoi Microsoftille kertakorvauksen siitä, ettei Microsoft syytä Novellin asiakkaita patenttirikkomuksista.
Linux-pioneeri Eban Moglenin mukaan Microsoft-Novell -sopimus kiertää GNU General Public -lisenssiä, joka on vallitseva lisenssi Linuxissa ja monissa muissa vapaissa ohjelmissa.
Moglen kumppaneineen on jo aloittanut työn porsaanreiän tukkimiseksi lisenssin seuraavassa kolmosversiossa. He aikovat lisätä siihen lauseen, jolla kaikki lisenssin käyttäjät lupaavat olla nostamatta syytteitä.
Lauseen ansiosta Microsoftin sopimus kääntyisi päälaelleen. Mikäli yksi käyttäjä olisi suojassa Microsoftin syytteiltä, kukaan muukaan ei voisi saada syytettä.
- Tällä hetkellä ei liene kovin vaikeaa saada Linux-yhteisön hyväksyntää muutokselle, Moglen totesi Reutersin mukaan. Hän arvioi, että muutos hyväksyttäneen viikkojen tai kuukausien kuluessa.
Asiassa voi kuitenkin olla mutka. Esimerkiksi InformationWeek muistuttaa blogissaan, että Linus Torvalds ei välttämättä hyväksy GPL3:a koskemaan Linuxia.
Paineita Red Hatille
Microsoft sanoo omistavansa tekijänoikeuksia osaan Linuxin teknologiasta, vaikka yhtiö ei olekaan määritellyt kyseisiä oikeuksia.
Microsoftin pääjohtaja Steve Ballmer sanoi haastattelussa hiljattain, että asiakkaat, jotka hankkivat Linuxin muilta kuin Novellilta, voivat joutua hankaluuksiin.
Asiantuntijoiden mukaan tämä lisää painetta Novellin kilpailijalle Red Hatille, joka voi joutua tekemään vastaavan sopimuksen Microsoftin kanssa.
Kumpikaan, Novell eikä Microsoft, halunneet kommentoida lisenssimuutoshanketta.
Kupruja Microsoftin ja Novellin yhteistyössä
Microsoftin ja Novellin marraskuun toisena päivänä solmima yhteistyösopimus on ajautunut vastatuuleen Steve Ballmerin avattua sanaisen arkkunsa viime viikolla. Ballmerin mukaan osasyy Microsoftin ja SUSE Linuxin jakelijan Novellin aiemmin marraskuussa solmimalle sopimukselle oli se, että Linux luokkaa Microsoftin immateriaalioikeuksia. Ballmerin ja kenties koko Microsoftin harmiksi Novellin toimitusjohtaja Ron Hovsepian kiistää Ballmerin sanomiset. Hän kirjoitti avoimen kirjeen avoimen lähdekoodin yhteisölle, jossa hän sanoi, ettei "Microsoftin kanssa solmittu sopimus ole minkään sortin myöntäminen siitä, että Linux rikkoisi Microsoftin immateriaalioikeuksia millään tavoin."
Hovsepianin mukaan Linuxin Windows-yhteensopivuus, jota Microsoftin ja Novellin oli tarkoitus kehittää yhteistyössä, tulisi hyödyttämään kaikkia Linux-käyttöjärjestelmätoimittajia. Novell tienaa sopimuksen myötä Microsoftilta lähes 350 miljoonaa dollaria. "Mielenkiintomme tässä sopimuksessa kohdistui yhteensopivuuden turvaamiseen ja myyntiyhteistyöhön, mutta Microsoft halusi sisällyttää sopimukseen myös patentit", Hovsepian kirjoitti. "Olemme eri mieltä Microsoftin antamista lausunnoista, jotka koskevat Linuxia ja patentteja. Kun patentteja koskeva osa lisättiin sopimukseen, Novell ei myöntänyt, että Linux tai mikään Novellin tuote loukkaisi Microsoftin patentteja", hän jatkoi. Lue juttu.
Microsoft voi joutua ongelmiin myös uuden GPL-lisenssin kanssa. GNU Public Licensen seuraava versio tulee sisältämään pykälän, joka kieltää lisenssin hyväksyjien väliset patenttiloukkaussyytökset. ZDNetin mukaan tämä tarkoittaisi sitä, että joko Microsoftin ja Novellin sopimus peruuntuu, tai Microsoft joutuu maksamaan hyvityksiä kaikille GNU/Linux-ohjelmistotoimittajille ja - käyttäjille. GPLv3 on toistaiseksi vielä varsin vaiheessa, koska osa avoimen lähdekoodin yhteisöstä - mukaan lukien Linus Torvalds - vastustaa lisenssin voimakkaita DRM:n vastaisia kohtia. Lue juttu.
Postittanut K2, 24.11.2006, kello 00:10. Lähde: ZDNet, Ecommercetimes
Tähän kysymykseen monet osaavat vastata helposti.
Itse kerran tein testin. En nimittäin bootannut konettani 8 päivään ja 22 tuntiin. Sitten en enää jaksanut koneen takkuilua. Monella koneen käyttäjistä saattaa olla suurempiakin ennätyksiä tässä.
Mutta kuinka monesti asia olisi yksinkertaista vain olla tekemättä mitään koneella, kunnes se toipuu lamaantumisestaan.
Tietysti on niitä päiviä jolloin kone vaatii sitä piristettä eli boottia.
Mutta eikös käyttöjärjestelmän tulisi toimia ilman sitäkin. Näin esimerkiksi toimii Linux-jakelut. Esimerkkinä tästä vaikka Ubuntu.
Vaikka kone ohjelma päivitti koko järjestelmän aina kerneliä myöten. Ubuntu vain suositteli boottia, ei "pakottanut". Vaan hienovaraisesti kertoo että ei välttämättä kaikki toimi.
Kuten taas XP tekee monesti sen ilman kysymistäkään ja jos kysyy ja sillä kertaa kieltäytyy bootista, tämän tästä ponnahtelee pieni kehotusikkuna aina eteen. Näin on monesti käynyt ainakin minulle. Tai sitten toinen vaihtoehto. Yön aikana kone päivittää itse- itsensä ja aamulla kun tulee koneelle onkin vain kirjautumis tilassa, eli kone boottas itsensä yöllä kun joku tärkeä kriittinen päivitys asentui koneelle. No onneksi ei ollut mitään tärkeää menossa ja kaikki oli tallennettuna. Mutta jos ei olisi ollutkaan...
Siispä kun vielä moni käyttää XP:tä ja eivät ole siirtyneet Linuxiin, niin tässä teille uusi taustakuva, joka muistuttaa siitä että ODOTA...
taustakuva
Tässä muutama lisää -Niko 12/10/06, 2:55pm
kuva1
kuva2
kuva3
kuva4
Ja yksi flash
Loppu kevennys.

